import { __awaiter, __decorate } from "tslib";
import { NotificationListener } from '@genesislcap/foundation-ui';
import { attr } from '@genesislcap/web-core';
import { customElement, html, ref } from '@microsoft/fast-element';
import * as Notifications from '@openfin/workspace/notifications';
import { IndicatorColor } from '@openfin/workspace/notifications';
import { init } from '@openfin/workspace-platform';
const PLATFORM_ID = 'use-notifications';
const PLATFORM_ICON = 'http://localhost:8080/images/icon-dot.png';
const PLATFORM_TITLE = 'Use Notifications';
const OpenfinGensisPriorityMap = {
    Information: 1,
    Warning: 2,
    Serious: 3,
    Critical: 4,
};
const OpenfinGensisColorMap = {
    Information: 'blue',
    Warning: 'yellow',
    Serious: 'red',
    Critical: 'red',
};
function initializeWorkspacePlatform() {
    return __awaiter(this, void 0, void 0, function* () {
        yield init({
            browser: {
                defaultWindowOptions: {
                    icon: PLATFORM_ICON,
                    workspacePlatform: {
                        pages: [],
                        favicon: PLATFORM_ICON,
                    },
                },
            },
        });
    });
}
function initializeNotifications() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log('initialise notifications');
        yield Notifications.register({
            notificationsPlatformOptions: {
                id: PLATFORM_ID,
                icon: PLATFORM_ICON,
                title: PLATFORM_TITLE,
            },
        });
        yield Notifications.addEventListener('notification-action', (event) => {
            console.log(event, 'notification-action button clicked');
        });
    });
}
/**
 * @tagname openfin-notification-listener
 * @public
 * @remarks
 * This component extends the notification listener class and overrides the logic for showing the toast message to instead dispatch the event to the openfin notifications bus.
 */
let OpenfinNotifications = class OpenfinNotifications extends NotificationListener {
    constructor() {
        super(...arguments);
        this.toast = 'transient';
    }
    connectedCallback() {
        const _super = Object.create(null, {
            connectedCallback: { get: () => super.connectedCallback }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield _super.connectedCallback.call(this);
            yield initializeWorkspacePlatform();
            yield initializeNotifications();
            const notification = {
                title: 'Simple Notification',
                body: 'This is a simple notification',
                toast: 'transient',
                category: 'default',
                template: 'markdown',
                id: `${Math.random()}`,
                soundOptions: {
                    mode: 'silent',
                },
                platform: PLATFORM_ID,
            };
            yield Notifications.create(notification);
        });
    }
    showNotificationToast(row) {
        return __awaiter(this, void 0, void 0, function* () {
            const { HEADER: title, MESSAGE: body, NOTIFY_SEVERITY: type } = row;
            const notification = {
                title,
                body,
                priority: OpenfinGensisPriorityMap[type],
                toast: this.toast || 'transient',
                category: type,
                template: 'markdown',
                id: `${Math.random()}`,
                soundOptions: {
                    mode: 'silent',
                },
                indicator: {
                    text: title,
                    color: OpenfinGensisColorMap[type],
                    fallback: IndicatorColor.BLUE,
                },
                buttons: this.mapToastButtons(this.toastButtons),
                platform: PLATFORM_ID,
            };
            try {
                yield Notifications.create(notification);
            }
            catch (e) {
                console.error('Openfin notifications error', e);
            }
        });
    }
    mapToastButtons(toastButtons) {
        if (!toastButtons) {
            return null;
        }
        return toastButtons.map((t) => {
            return {
                title: t.placeholder,
                type: 'button',
                onClick: {
                    cta: true,
                    task: 'acknowledge-task',
                    customData: {
                        message: 'Notification button clicked',
                    },
                },
            };
        });
    }
};
__decorate([
    attr
], OpenfinNotifications.prototype, "toast", void 0);
OpenfinNotifications = __decorate([
    customElement({
        name: 'openfin-notification-listener',
        template: html `
    <template ${ref('notificationListener')}>
      <slot></slot>
    </template>
  `,
    })
], OpenfinNotifications);
export { OpenfinNotifications };
